const Config = require('./config');

const createError = require('http-errors');
const express = require('express');
const path = require('path');
const cookieParser = require('cookie-parser');
const logger = require('morgan');
const sassMiddleware = require('node-sass-middleware');

const indexRouter = require('./routes/index');
const usersRouter = require('./routes/users');
const authRouter = require('./routes/api/auth');
const userRouter = require('./routes/api/user');
const projectRouter = require('./routes/api/project');
const modelRouter = require('./routes/api/model');

const metamodelRouter = require('./routes/api/metamodel');

const bodyParser = require("body-parser");
const cors = require("cors");

var corsOptions = {
  origin: Config.ENVIROMENT === 'dev' ? Config.DEV_CORS : Config.PROD_CORS
};

let subadress = Config.ENVIROMENT === 'dev' ? '/api/' : '/';

const app = express();

app.use(cors(corsOptions));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: true }));

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'twig');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(sassMiddleware({
  src: path.join(__dirname, 'public'),
  dest: path.join(__dirname, 'public'),
  indentedSyntax: true, // true = .sass and false = .scss
  sourceMap: true
}));
app.use(express.static(path.join(__dirname, 'public')));

app.use('/', indexRouter);
app.use('/users', usersRouter);
app.use(subadress + 'auth', authRouter);
app.use(subadress + 'test', userRouter);

app.use(subadress + 'projects', projectRouter);
app.use(subadress + 'models', modelRouter);

app.use(subadress + 'metamodels', metamodelRouter);

// catch 404 and forward to error handler
app.use(function(req, res, next) {
  next(createError(404));
});

// error handler
app.use(function(err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get('env') === 'development' ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render('error');
});

const db = require("./models");

db.sequelize.sync();

module.exports = app;
