const db = require("../models");
const Project = db.project;
const Op = db.Sequelize.Op;

exports.createProject = (req, res) => {
    // Save Project to Database

    // Validate request
    if (!req.body.projectName && ! req.body.projectDescription) {
        res.status(400).send({
            message: "Content can not be empty!"
        });
        return;
    }

    // Create a Tutorial
    const project = {
        name: req.body.projectName,
        description: req.body.projectDescription,
        status: 'active',
        start: new Date().toString(),
        userId: req.userId
    };

    Project.create(project)
        .then(() => {
            res.status(200).send({ message: "Project was created successfully!"});
        })
        .catch(err => {
            res.status(500).send({ message: err.message });
        });
};

exports.getProjects = (req, res) => {
    const name = req.query.name;
    let condition = name ? { name: { [Op.like]: `%${name}%` }, userId: req.userId } : { userId: req.userId };

    Project.findAll({ where: condition })
        .then(data => {
            res.status(200).send(data);
        })
        .catch(err => {
            res.status(500).send({
                message:
                    err.message || "Some error occurred while retrieving projects."
            });
        });
};

exports.deleteProject = (req, res) => {
    const id = req.body.id;

    Project.destroy({
        where: { id: id, userId: req.userId }
    })
        .then(() => {
            res.status(200).send({
                message: "Project was deleted successfully!"
            });
        })
        .catch(err => {
            res.status(500).send({
                message: "Could not delete project with id=" + id
            });
        });
};

exports.readProject = (req, res) => {
    const id = req.params.id;

    Project.findByPk(id)
        .then(data => {
            res.status(200).send(data);
        })
        .catch(err => {
            res.status(500).send({
                message: "Error retrieving Project with id=" + id
            });
        });
};

exports.updateProject = (req, res) => {
    const id = req.query.id;

    // Save Project to Database
    if (!req.body.projectName || !req.body.projectDescription) {
        res.status(400).send({
            message: "Content can not be empty!"
        });
        return;
    }

    // Create a Tutorial
    const port = {
        name: req.body.projectName,
        description: req.body.projectDescription,
    };

    Project.update(port, {
        where: { id: id }
    })
        .then(() => {
            res.status(200).send({
                message: "Project was updated successfully."
            });
        })
        .catch(() => {
            res.status(500).send({
                message: "Error updating project with id=" + id
            });
        });
};