const db = require("../models");
const Project = db.project;
const Model = db.model;
const User = db.user;
const Op = db.Sequelize.Op;

exports.createProject = (req, res) => {
    // Save Project to Database

    // Validate request
    if (!req.body.projectName) {
        return res.status(400).send({
            message: "Title can not be empty!"
        });

    }

    // Create a Tutorial
    const project = {
        title: req.body.projectName,
        description: req.body.projectDescription,
        published: req.body.projectPublished,
        status: 'active',
        start: new Date().toString(),
    };

    Project.create(project)
        .then((project) => {
            project.setUsers([req.userId]).then(() => {
                res.status(200).send({ message: "Project was created successfully!"});
            });
        })
        .catch(err => {
            res.status(500).send({ message: err.message });
        });
};

exports.getProjects = (req, res) => {
    const name = req.query.name;
    let condition = name ? { name: { [Op.like]: `%${name}%` } } : '';

    Project.findAll({
        where: condition,
        include: [{
            model: User,
            as: "users",
            through: {
                attributes: ["projectId", "userId"],
            },
        }]
    })
        .then(data => {
            let userProjects = [];
            data.forEach((element) => {
                if(element.users[0].id === req.userId) {
                    userProjects.push(element)
                } else if(element.published) {
                    userProjects.push(element)
                }
            });
            res.status(200).send(userProjects);
        })
        .catch(err => {
            res.status(500).send({
                message:
                    err.message || "Some error occurred while retrieving projects."
            });
        });
};

exports.deleteProject = (req, res) => {
    const id = req.query.id;

    Project.findByPk(id,
        {
            include: [{
                model: User,
                as: "users",
                through: {
                    attributes: ["projectId", "userId"],
                },
            }]
        })
        .then(data => {
            if(data.users[0].id === req.userId) {
                Model.destroy({
                    where: { projectId: id }
                })
                    .then(() => {
                        Project.destroy({
                            where: { id: id }
                        })
                            .then(() => {
                                res.status(200).send({
                                    message: "Project was deleted successfully!"
                                });
                            })
                            .catch(err => {
                                res.status(500).send({
                                    message: "Could not delete project with id=" + id
                                });
                            });
                    })
                    .catch(err => {
                        res.status(500).send({
                            message: "Could not delete project. Error: " + err
                        });
                    });
            } else {
                res.status(500).send({
                    message: "Unauthorized"
                });
            }
        })
        .catch(err => {
            res.status(500).send({
                message: "Error retrieving Project with id=" + id
            });
        });
};

exports.readProject = (req, res) => {
    const id = req.params.id;

    Project.findByPk(id)
        .then(data => {
            res.status(200).send(data);
        })
        .catch(err => {
            res.status(500).send({
                message: "Error retrieving Project with id=" + id
            });
        });
};

exports.updateProject = (req, res) => {
    const id = req.query.id;

    // Save Project to Database
    if (!req.body.projectName) {
        return res.status(400).send({
            message: "Title can not be empty!"
        });

    }

    // Create a Tutorial
    const port = {
        title: req.body.projectName,
        description: req.body.projectDescription,
    };

    Project.findByPk(id,
        {
            include: [{
                model: User,
                as: "users",
                through: {
                    attributes: ["projectId", "userId"],
                },
            }]
        })
        .then(data => {
            if(data.users[0].id === req.userId || data.published) {
                if(data.users[0].id === req.userId) {
                    port.published = req.body.projectPublished;
                }
                Project.update(port, {
                    where: { id: id }
                })
                    .then(() => {
                        res.status(200).send({
                            message: "Project was updated successfully."
                        });
                    })
                    .catch(() => {
                        res.status(500).send({
                            message: "Error updating project with id=" + id
                        });
                    });
            } else {
                res.status(500).send({
                    message: "Unauthorized"
                });
            }
        })
        .catch(err => {
            res.status(500).send({
                message: "Error retrieving Project with id=" + id
            });
        });
};